# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [3.0.1](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@2.1.3...@visa/charts-python@3.0.1) (2024-11-15)

### Bug Fixes

- manually bump charts-python js package for fix ([7935678](https://github.com/visa/visa-chart-components/commit/793567895da157eb8282f833c17f310034e9896b))
- package and version bumps for 8.0.1 fix release ([a021bdc](https://github.com/visa/visa-chart-components/commit/a021bdc3906bff451395cc60aca1d5cafa14d131))

# [3.0.0](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@2.1.3...@visa/charts-python@3.0.0) (2024-10-25)

### chore

- bump to stencil 4.21.0 and angular 17 ([e056f8c](https://github.com/visa/visa-chart-components/commit/e056f8c95e59ee58ce9facbd4e57552586746f30))

## [2.1.3](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@2.1.1...@visa/charts-python@2.1.3) (2024-02-16)

**Note:** Version bump only for package @visa/charts-python

## [2.1.2](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@2.1.1...@visa/charts-python@2.1.2) (2024-02-09)

**Note:** Version bump only for package @visa/charts-python

## [2.1.1](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@2.1.0...@visa/charts-python@2.1.1) (2023-09-28)

**Note:** Version bump only for package @visa/charts-python

# [2.1.0](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@2.0.0...@visa/charts-python@2.1.0) (2023-06-16)

### Bug Fixes

- bump and fix charts-python package ([64ebe55](https://github.com/visa/visa-chart-components/commit/64ebe55f2ddefaf1994e62f752ffd0d95edde026))

### Features

- utils-dev and charts-python bumps ([35b5657](https://github.com/visa/visa-chart-components/commit/35b565778dde994337f60284bf179b73976cc78b))

# [2.0.0](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@1.1.0...@visa/charts-python@2.0.0) (2023-02-01)

### chore

- d3-color bump to 3.1.0 and resolutions ([dd9a2fb](https://github.com/visa/visa-chart-components/commit/dd9a2fb369c44bab6607acb5229ceb656dce5561))

### BREAKING CHANGES

- d3-color bump to 3.1.0, IE11 support no longer maintained. If you need to support IE11, you should stick with the previous release.

# [1.1.0](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@1.0.0...@visa/charts-python@1.1.0) (2023-01-13)

### Features

- feat bump charts-python bundle for dataKeyNames prop and more ([e9586b9](https://github.com/visa/visa-chart-components/commit/e9586b9ad6412b3b7563f197a7a40e136fa8de99))

# 1.0.0 (2022-07-28)

### chore

- initial deployment of charts-python package ([af68e9f](https://github.com/visa/visa-chart-components/commit/af68e9fc88253bb4c40391ae6b78441aca570e76))

### BREAKING CHANGES

- initial deployment of charts-python package

Co-authored-by: Chris DeMartini <74268675+chris-demartini@users.noreply.github.com>
